==============
Analytics Core
==============


.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - | |Pylint|
    * - package
      - | |version| |wheel| |supported-versions| |supported-implementations|
      
.. |docs| image:: https://readthedocs.org/projects/acore/badge/?style=flat
    :target: https://analytics-core.readthedocs.io/
    :alt: Documentation Status

.. |Pylint| image:: https://github.com/Multiomics-Analytics-Group/acore/actions/workflows/tox-gha.yml/badge.svg
    :alt: GitHub Actions Tox Status
    :target: https://github.com/Multiomics-Analytics-Group/acore/actions/workflows/tox.yml

.. |version| image:: https://img.shields.io/pypi/v/acore.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/acore

.. |wheel| image:: https://img.shields.io/pypi/wheel/acore.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/project/acore

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/acore.svg
    :alt: Supported versions
    :target: https://pypi.org/project/acore

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/acore.svg
    :alt: Supported implementations
    :target: https://pypi.org/project/acore

.. end-badges




A Python package with statistical functions to analyse multimodal molecular data


* Free software: GNU General Public License v3
* Documentation: https://analytics-core.readthedocs.io.


PyPI Installation
=================

::

    pip install acore

You can also install the in-development version with::

    pip install https://github.com/Multiomics-Analytics-Group/acore/archive/main.zip



Development
===========

To run all the tests run::

    pytest 
